@@ -69,8 +69,28 @@ import debug
 import eventsynthesizer
 import orca_state
 import settings
-from platform import tablesdir
 
+# Right now, the orca autogen.sh/configure needs a priori knowledge of
+# where the liblouis tables are.  When running autogen.sh/configure,
+# platform.py:tablesdir will be set to point to the liblouis table
+# location.  If not found, it will be the empty string.  We need to
+# capture that error condition, otherwise braille contraction will
+# just plain fail.  See also bgo#610134.  [[TODO: WDW - see if the
+# liblouis bindings can give us the tablesdir information at runtime
+# http://code.google.com/p/liblouis/issues/detail?id=9]]
+#
+from platform import tablesdir
+if louis and not tablesdir:
+    debug.println(debug.LEVEL_SEVERE,
+                  "Contraction tables for liblouis cannot be found.")
+    debug.println(debug.LEVEL_SEVERE,
+                  "This usually means orca was built before")
+    debug.println(debug.LEVEL_SEVERE,
+                  "liblouis was installed. Contracted braille will")
+    debug.println(debug.LEVEL_SEVERE,
+                  "not be available.")
+    louis = None
+    
 from orca_i18n import _                          # for gettext support
 
 # The braille monitor
@@ -501,6 +521,13 @@ class Component(Region):
         associated with this region.  Note that the zeroeth character may have
         been scrolled off the display."""
 
+        if orca_state.activeScript and orca_state.activeScript.utilities.\
+           grabFocusBeforeRouting(self.accessible, offset):
+            try:
+                self.accessible.queryComponent().grabFocus()
+            except:
+                pass
+
         try:
             action = self.accessible.queryAction()
         except:
@@ -679,7 +706,8 @@ class Text(Region):
         if caretOffset < 0:
             return
 
-        orca_state.activeScript.setCaretOffset(self.accessible, caretOffset)
+        orca_state.activeScript.utilities.setCaretOffset(
+            self.accessible, caretOffset)
 
     def getAttributeMask(self, getLinkMask=True):
         """Creates a string which can be used as the attrOr field of brltty's
@@ -728,14 +756,14 @@ class Text(Region):
                 n += 1
 
         if attrIndicator:
-            enabledAttributes = script.attributeStringToDictionary(
+            keys, enabledAttributes = script.utilities.stringToKeysAndDict(
                 settings.enabledBrailledTextAttributes)
 
             offset = self.lineOffset
             while offset < lineEndOffset:
                 attributes, startOffset, endOffset = \
-                            script.getTextAttributes(self.accessible,
-                                                     offset, True)
+                    script.utilities.textAttributes(self.accessible,
+                                                    offset, True)
                 if endOffset <= offset:
                     break
                 mask = settings.TEXT_ATTR_BRAILLE_NONE
@@ -752,7 +780,7 @@ class Text(Region):
                         regionMask[i] |= attrIndicator
 
         if selIndicator:
-            selections = script.getAllTextSelections(self.accessible)
+            selections = script.utilities.allTextSelections(self.accessible)
             for startOffset, endOffset in selections:
                 maskStart = max(startOffset - self.lineOffset, 0)
                 maskEnd = min(endOffset - self.lineOffset, stringLength)
@@ -859,7 +887,8 @@ class ReviewText(Region):
         been scrolled off the display."""
 
         caretOffset = self.getCaretOffset(offset)
-        orca_state.activeScript.setCaretOffset(self.accessible, caretOffset)
+        orca_state.activeScript.utilities.setCaretOffset(
+            self.accessible, caretOffset)
 
 class Line:
     """A horizontal line on the display.  Each Line is composed of a sequential
