@@ -750,7 +750,8 @@ class SpeechServer(speechserver.SpeechServer):
         """
         chname = chnames.getCharacterName(character)
         if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            chname = orca_state.activeScript.adjustForPronunciation(chname)
+            chname = orca_state.activeScript.\
+                utilities.adjustForPronunciation(chname)
         self.speak(chname, acss)
 
     def speakUtterances(self, utterances, acss=None, interrupt=True):
@@ -904,6 +905,14 @@ class SpeechServer(speechserver.SpeechServer):
 
         return newText
 
+    def updatePunctuationLevel(self):
+        """ Punctuation level changed, inform this speechServer. """
+
+        # We dont need to do anything, __addVerbalizedPunctuation
+        # already does this work for us.
+        #
+        pass
+
     def __speak(self, text=None, acss=None, interrupt=True):
         """Speaks all queued text immediately.  If text is not None,
         it is added to the queue before speaking.
@@ -961,8 +970,8 @@ class SpeechServer(speechserver.SpeechServer):
             # On failure, remember what we said, reset our connection to the
             # speech synthesis driver, and try to say it again.
             #
-            debug.printException(debug.LEVEL_SEVERE)
-            debug.println(debug.LEVEL_SEVERE, "Restarting speech...")
+            debug.printException(debug.LEVEL_WARNING)
+            debug.println(debug.LEVEL_WARNING, "Restarting speech...")
             self.reset()
             return -1
 
